#!/bin/bash

#######################################################################
# Program: trackbuild.emacs
# Purpose: Build the emacs packages for ARMedslack
# Author : Stuart Winter <stuart@armedslack.org>
#######################################################################

# Ensure slacktrack/altertrack is installed:
which altertrack >/dev/null 2>&1 || { echo "Cannot build without slacktrack" ; exit 1 ;}
TRACKTYPE=altertrack

# Paths to skeleton port's source & real Slackware source tree:
export CWD=$SLACKSOURCE/$PKGSERIES
export PORTCWD=$PWD

# Determine the CFLAGS for the known architectures:
case $PORTARCH in
   arm)     export SLKCFLAGS="-O2 -march=armv3 -mtune=xscale" ;;
   powerpc) export SLKCFLAGS="-O2" ;;
   sparc)   export SLKCFLAGS="-O2" ;;
esac

# Temporary build locations:
export TMPBUILD=$TMP/build-$PACKAGE
export PKG=$TMP/package-$PACKAGE
mkpkgdirs # Delete & re-create temporary directories then cd into $TMPBUILD
rm -rf $TMPBUILD

# If specified in slackdev.config, we'll delete the old copy of the
# package from our package store.
if [ "${DELETEOLDPKGS}" = "Yes" ]; then
   rm -f $PKGSTORE/$PKGSERIES/$PACKAGE-*.{tgz,txt}
fi

# Stop daemons/processes which tend to modify the contents of the filesystem:
altertrackprep

# Launch the compile/install script:
cd $PORTCWD
$TRACKTYPE $ALTERTRACKOPTS \
           --notidy \
           -R "$PORTCWD/postbuild.sh $VERSION" \
           -T$TMPBUILD \
           -l$PORTCWD/build.log \
           -b$PKGSTORE/$PKGSERIES \
           -OcQp $SLACKPACKAGE ./$PACKAGE.build $VERSION
